From 8e528fd7bf2e2bd1e20c7e7de5eefb26bf6b19d9 Mon Sep 17 00:00:00 2001
From: Aleksander Machniak <alec@alec.pl>
Date: Wed, 23 May 2012 14:09:57 -0400
Subject: [PATCH] hide_blockquote - a new plugin for hiding citation blocks
---
program/include/rcube_message.php | 27 +++++++++++++++++++--------
1 files changed, 19 insertions(+), 8 deletions(-)
diff --git a/program/include/rcube_message.php b/program/include/rcube_message.php
index 76246a2..8f1432f 100644
--- a/program/include/rcube_message.php
+++ b/program/include/rcube_message.php
@@ -164,11 +164,13 @@
/**
* Get content of a specific part of this message
*
* @param string $mime_id Part MIME-ID
* @param resource $fp File pointer to save the message part
* @return string Part content
*/
- public function get_part_content($mime_id, $fp=NULL)
+ public function get_part_content($mime_id, $fp = null, $skip_charset_conv = false)
{
if ($part = $this->mime_parts[$mime_id]) {
// stored in message structure (winmail/inline-uuencode)
@@ -179,7 +181,7 @@
return $fp ? true : $part->body;
}
// get from IMAP
- return $this->storage->get_message_part($this->uid, $mime_id, $part, NULL, $fp);
+ return $this->storage->get_message_part($this->uid, $mime_id, $part, NULL, $fp, $skip_charset_conv);
} else
return null;
}
@@ -651,23 +653,29 @@
$parts = array();
// FIXME: line length is max.65?
- $uu_regexp = '/begin [0-7]{3,4} ([^\n]+)\n(([\x21-\x7E]{0,65}\n)+)`\nend/s';
+ $uu_regexp = '/begin [0-7]{3,4} ([^\n]+)\n/s';
if (preg_match_all($uu_regexp, $part->body, $matches, PREG_SET_ORDER)) {
- // remove attachments bodies from the message body
- $part->body = preg_replace($uu_regexp, '', $part->body);
// update message content-type
$part->ctype_primary = 'multipart';
$part->ctype_secondary = 'mixed';
$part->mimetype = $part->ctype_primary . '/' . $part->ctype_secondary;
+ $uu_endstring = "`\nend\n";
// add attachments to the structure
foreach ($matches as $pid => $att) {
+ $startpos = strpos($part->body, $att[1]) + strlen($att[1]) + 1; // "\n"
+ $endpos = strpos($part->body, $uu_endstring);
+ $filebody = substr($part->body, $startpos, $endpos-$startpos);
+
+ // remove attachments bodies from the message body
+ $part->body = substr_replace($part->body, "", $startpos, $endpos+strlen($uu_endstring)-$startpos);
+
$uupart = new rcube_message_part;
$uupart->filename = trim($att[1]);
$uupart->encoding = 'stream';
- $uupart->body = convert_uudecode($att[2]);
+ $uupart->body = convert_uudecode($filebody);
$uupart->size = strlen($uupart->body);
$uupart->mime_id = 'uu.' . $part->mime_id . '.' . $pid;
@@ -678,6 +686,9 @@
$parts[] = $uupart;
unset($matches[$pid]);
}
+
+ // remove attachments bodies from the message body
+ $part->body = preg_replace($uu_regexp, '', $part->body);
}
return $parts;
@@ -164,11 +164,13 @@
* Get content of a specific part of this message
*
- * @param string $mime_id Part MIME-ID
- * @param resource $fp File pointer to save the message part
+ * @param string $mime_id Part MIME-ID
+ * @param resource $fp File pointer to save the message part
+ * @param boolean $skip_charset_conv Disables charset conversion
+ *
* @return string Part content
*/
--
Gitblit v1.9.1